@@ -32,6 +32,7 @@ def get_tiddlers_from_recipe(recipe, environ=None):
         if isinstance(bag, basestring):
             bag = Bag(name=bag)
         if store:
+            bag.skinny = True
             bag = store.get(bag)
         for tiddler in filter_tiddlers_from_bag(bag, filter_string):
             uniquifier[tiddler.title] = tiddler
@@ -61,7 +62,8 @@ def determine_tiddler_bag_from_recipe(recipe, tiddler, environ=None):
         # the store. If there's not, then we can just use the list that is
         # already in the bag, saving a bit of time.
         if filter_string:
-            for candidate_tiddler in filter_tiddlers_from_bag(bag, filter_string):
+            for candidate_tiddler in filter_tiddlers_from_bag(bag,
+                    filter_string):
                 if tiddler.title == candidate_tiddler.title:
                     return bag
         else:
@@ -87,7 +89,8 @@ def determine_bag_for_tiddler(recipe, tiddler, environ=None):
         # ignore the bag and make a new bag
         tmpbag = Bag(filter_string, tmpbag=True)
         tmpbag.add_tiddler(tiddler)
-        for candidate_tiddler in filter_tiddlers_from_bag(tmpbag, filter_string):
+        for candidate_tiddler in filter_tiddlers_from_bag(tmpbag,
+                filter_string):
             if tiddler.title == candidate_tiddler.title:
                 if isinstance(bag, basestring):
                     bag = Bag(name=bag)
@@ -102,6 +105,9 @@ def get_tiddlers_from_bag(bag):
     """
 
     if bag.store:
+        if hasattr(bag, 'skinny') and bag.skinny:
+            bag.skinny = False
+            bag = bag.store.get(bag)
         for tiddler in bag.gen_tiddlers():
             try:
                 tiddler = bag.store.get(tiddler)
@@ -109,6 +115,9 @@ def get_tiddlers_from_bag(bag):
                 # XXX do more here?
                 pass
             yield tiddler
+    else:
+        for tiddler in bag.gen_tiddlers():
+            yield tiddler
 
 
 def filter_tiddlers_from_bag(bag, filters):
@@ -119,13 +128,18 @@ def filter_tiddlers_from_bag(bag, filters):
     """
     store = bag.store
 
+    if bag.tmpbag or bag.revbag or bag.searchbag:
+        indexable = False
+    else:
+        indexable = bag
+
     # XXX isinstance considered harmful
     if isinstance(filters, basestring):
         filters, leftovers = parse_for_filters(filters)
     if store:
-        return recursive_filter(filters, get_tiddlers_from_bag(bag))
+        return recursive_filter(filters, get_tiddlers_from_bag(bag), indexable=indexable)
     else:
-        return recursive_filter(filters, bag.gen_tiddlers())
+        return recursive_filter(filters, bag.gen_tiddlers(), indexable=indexable)
 
 
 def _recipe_template(environ):
